Listen to the Tests: Design feedback

This is a Samman Learning Hour facilitated by Emily Bache.

Learning Hour on refactoring legacy code, with a focus on design feedback from tests.

Learning Hour PDF

See the PDF below for the “Listen to the Tests: Design feedback” Learning Hour: